@@ -144,7 +144,7 @@ class PloomberClient:
         Notebook object
 
     display_output : bool, default=False
-        If True, it prints whatever output the notebook prints.
+        If True, it prints the same output the notebook prints.
 
     Examples
     --------
@@ -165,24 +165,31 @@ class PloomberClient:
         self._display_stdout = display_stdout
 
     @classmethod
-    def from_path(cls, path):
+    def from_path(cls, path, display_stdout=False):
         """Initialize client from a path to a notebook
 
-
         Parameters
         ----------
         path : str
             Path to the ``.ipynb`` file
 
+        display_output : bool, default=False
+            If True, it prints the same output the notebook prints.
+
+        Notes
+        -----
+        .. versionchanged:: 0.0.18
+            Added ``display_stdout`` argument.
 
         Examples
         --------
         >>> from ploomber_engine.ipython import PloomberClient
-        >>> client = PloomberClient.from_path("examples/nb.ipynb")
+        >>> client = PloomberClient.from_path("nb.ipynb")
         >>> out = client.execute()
+
         """
         nb = nbformat.read(path, as_version=nbformat.NO_CONVERT)
-        return cls(nb)
+        return cls(nb, display_stdout=display_stdout)
 
     def execute_cell(self, cell, cell_index, execution_count, store_history):
         if self._shell is None:
@@ -237,9 +244,24 @@ class PloomberClient:
         nb
             Notebook object
         """
+        original = InteractiveShell._instance
+
         with self:
             self._execute()
 
+        if original is not None:
+            # restore original instance
+            InteractiveShell._instance = original
+
+            # restore inline matplotlib
+            try:
+                from matplotlib_inline.backend_inline import configure_inline_support
+            except ModuleNotFoundError:
+                pass
+            else:
+                configure_inline_support(original, "inline")
+                original.run_line_magic("matplotlib", "inline")
+
         return self._nb
 
     def get_namespace(self):
